@@ -20,12 +20,6 @@
 #ifndef BLOSC2_H
 #define BLOSC2_H
 
-#include <limits.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <stdbool.h>
-#include <stdio.h>
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -43,6 +37,12 @@ extern "C" {
 #define getpid _getpid
 #endif
 
+#include <limits.h>
+#include <stdlib.h>
+#include <stdint.h>
+#include <stdbool.h>
+#include <stdio.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -90,10 +90,10 @@ extern "C" {
 /* Version numbers */
 #define BLOSC2_VERSION_MAJOR    2    /* for major interface/format changes  */
 #define BLOSC2_VERSION_MINOR    9    /* for minor interface/format changes  */
-#define BLOSC2_VERSION_RELEASE  1    /* for tweaks, bug-fixes, or development */
+#define BLOSC2_VERSION_RELEASE  2    /* for tweaks, bug-fixes, or development */
 
-#define BLOSC2_VERSION_STRING   "2.9.1"  /* string version.  Sync with above! */
-#define BLOSC2_VERSION_DATE     "$Date:: 2023-05-10 #$"    /* date version */
+#define BLOSC2_VERSION_STRING   "2.9.2"  /* string version.  Sync with above! */
+#define BLOSC2_VERSION_DATE     "$Date:: 2023-05-18 #$"    /* date version */
 
 
 /* The maximum number of dimensions for Blosc2 NDim arrays */
@@ -194,30 +194,28 @@ enum {
 };
 
 enum {
-    BLOSC2_DEFINED_TUNE_START = 0,
-    BLOSC2_DEFINED_TUNE_STOP = 31,
-    //!< Blosc-defined tunes must be between 0 - 31.
-    BLOSC2_GLOBAL_REGISTERED_TUNE_START = 32,
-    BLOSC2_GLOBAL_REGISTERED_TUNE_STOP = 159,
-    //!< Blosc-registered tunes must be between 31 - 159.
-    BLOSC2_GLOBAL_REGISTERED_TUNES = 0,
-    //!< Number of Blosc-registered tunes at the moment.
-    BLOSC2_USER_REGISTERED_TUNE_START = 160,
-    BLOSC2_USER_REGISTERED_TUNE_STOP = 255,
-    //!< User-defined tunes must be between 160 - 255.
+    BLOSC2_DEFINED_TUNER_START = 0,
+    BLOSC2_DEFINED_TUNER_STOP = 31,
+    //!< Blosc-defined tuners must be between 0 - 31.
+    BLOSC2_GLOBAL_REGISTERED_TUNER_START = 32,
+    BLOSC2_GLOBAL_REGISTERED_TUNER_STOP = 159,
+    //!< Blosc-registered tuners must be between 31 - 159.
+    BLOSC2_GLOBAL_REGISTERED_TUNERS = 0,
+    //!< Number of Blosc-registered tuners at the moment.
+    BLOSC2_USER_REGISTERED_TUNER_START = 160,
+    BLOSC2_USER_REGISTERED_TUNER_STOP = 255,
+    //!< User-defined tuners must be between 160 - 255.
 };
 
 /**
- * @brief Codes for the different tunes shipped with Blosc
+ * @brief Codes for the different tuners shipped with Blosc
  */
 enum {
-#ifndef BLOSC_H
     BLOSC_STUNE = 0,
-#endif // BLOSC_H
-    BLOSC_LAST_TUNE = 1,
-    //!< Determine the last tune defined by Blosc.
-    BLOSC_LAST_REGISTERED_TUNE = BLOSC2_GLOBAL_REGISTERED_TUNE_START + BLOSC2_GLOBAL_REGISTERED_TUNES - 1,
-    //!< Determine the last registered tune. It is used to check if a tune is registered or not.
+    BLOSC_LAST_TUNER = 1,
+    //!< Determine the last tuner defined by Blosc.
+    BLOSC_LAST_REGISTERED_TUNE = BLOSC2_GLOBAL_REGISTERED_TUNER_START + BLOSC2_GLOBAL_REGISTERED_TUNERS - 1,
+    //!< Determine the last registered tuner. It is used to check if a tuner is registered or not.
 };
 
 enum {
@@ -1026,6 +1024,8 @@ typedef int     (*blosc2_truncate_cb)(void *stream, int64_t size);
 typedef struct {
   uint8_t id;
   //!< The IO identifier.
+  char* name;
+  //!< The IO name.
   blosc2_open_cb open;
   //!< The IO open callback.
   blosc2_close_cb close;
@@ -1048,15 +1048,15 @@ typedef struct {
  */
 typedef struct {
   uint8_t id;
+  const char *name;
   //!< The IO identifier.
   void *params;
   //!< The IO parameters.
 } blosc2_io;
 
-static blosc2_io_cb BLOSC2_IO_CB_DEFAULTS = {0};
-
 static const blosc2_io BLOSC2_IO_DEFAULTS = {
     .id = BLOSC2_IO_FILESYSTEM,
+    .name = "filesystem",
     .params = NULL,
 };
 
@@ -1080,33 +1080,30 @@ typedef struct blosc2_context_s blosc2_context;   /* opaque type */
 
 typedef struct {
   void (*init)(void * config, blosc2_context* cctx, blosc2_context* dctx);
-  //!< Initialize tune.
+  //!< Initialize tuner. Keep in mind dctx may be NULL. This should memcpy the cctx->tuner_params.
   void (*next_blocksize)(blosc2_context * context);
-  //!< Only compute the next blocksize. Only it is executed if tune is not initialized.
+  //!< Only compute the next blocksize. Only it is executed if tuner is not initialized.
   void (*next_cparams)(blosc2_context * context);
-  //!< Compute the next cparams. Only is executed if tune is initialized.
+  //!< Compute the next cparams. Only is executed if tuner is initialized.
   void (*update)(blosc2_context * context, double ctime);
-  //!< Update the tune parameters.
+  //!< Update the tuner parameters.
   void (*free)(blosc2_context * context);
-  //!< Free the tune.
+  //!< Free the tuner.
   int id;
-  //!< The tune id
+  //!< The tuner id
   char *name;
-  //!< The tune name
-}blosc2_tune;
+  //!< The tuner name
+} blosc2_tuner;
 
 
 /**
- * @brief Register locally a user-defined tune in Blosc.
+ * @brief Register locally a user-defined tuner in Blosc.
  *
- * @param tune The tune to register.
+ * @param tuner The tuner to register.
  *
  * @return 0 if succeeds. Else a negative code is returned.
  */
-BLOSC_EXPORT int register_tune_private(blosc2_tune *tune);
-
-
-static int g_tune = BLOSC_STUNE;
+BLOSC_EXPORT int register_tuner_private(blosc2_tuner *tuner);
 
 
 /**
@@ -1194,10 +1191,10 @@ typedef struct {
   //!< The prefilter function.
   blosc2_prefilter_params *preparams;
   //!< The prefilter parameters.
-  void *tune_params;
+  void *tuner_params;
   //!< Tune configuration.
-  int tune_id;
-  //!< The tune id.
+  int tuner_id;
+  //!< The tuner id.
   bool instr_codec;
   //!< Whether the codec is instrumented or not
   void *codec_params;
@@ -1708,10 +1705,10 @@ typedef struct blosc2_schunk {
   //<! The array of variable-length metalayers.
   int16_t nvlmetalayers;
   //!< The number of variable-length metalayers.
-  void *tune_params;
+  void *tuner_params;
   //!< Tune configuration.
-  int tune_id;
-  //<! Id for tune
+  int tuner_id;
+  //<! Id for tuner
   int8_t ndim;
   //<! The ndim (mainly for ZFP usage)
   int64_t *blockshape;
